<div class="mooch mooch--banktransfer">
  <form method="post" action="{{ confirm_url }}">
    {% csrf_token %}
    <input type="hidden" name="id" value="{{ payment.id.hex }}">
    <button type="submit">{{ moocher.title }}</button>
  </form>
</div>
