<div class="mooch mooch--postfinance">

  <form method="post" action="https://e-payment.postfinance.ch/ncol/{{ mode }}/orderstandard.asp" id="postfinanceform">
    {% for key, value in postfinance.items %}<input type="hidden" name="{{ key }}" value="{{ value }}">
    {% endfor %}

    <!--
    <input type="hidden" name="CN" value="{{ donation.full_name }}">
    <input type="hidden" name="owneraddress" value="{{ donation.billing_address }}">
    <input type="hidden" name="ownerZIP" value="{{ donation.billing_zip_code }}">
    <input type="hidden" name="ownertown" value="{{ donation.billing_city }}">
    <input type="hidden" name="ownercty" value="{{ donation.billing_country }}">
    -->

    <input type="hidden" name="accepturl" value="{{ success_url }}">
    <input type="hidden" name="declineurl" value="{{ failure_url }}">
    <input type="hidden" name="exceptionurl" value="{{ failure_url }}">
    <input type="hidden" name="cancelurl" value="{{ failure_url }}">

    <input type="hidden" name="PMLIST" value="{{ payment_methods|join:';' }}">

    <button type="submit">{{ moocher.title }}</button>
  </form>

</div>
